@@ -8,7 +8,6 @@ __BEGIN_DECLS
 #define __WANT_POSIX1B_SIGNALS__
 
 #include <sys/types.h>
-#include <sys/time.h>
 
 #define NSIG		32
 
@@ -465,6 +464,36 @@ struct sigaction {
 #define sa_handler	_u._sa_handler
 #define sa_sigaction	_u._sa_sigaction
 
+
+#define SIGEV_SIGNAL    0       /* notify via signal */
+#define SIGEV_NONE      1       /* other notification: meaningless */
+#define SIGEV_THREAD    2       /* deliver via thread creation */
+#define SIGEV_THREAD_ID 4       /* deliver to thread */
+
+#define SIGEV_MAX_SIZE  64
+#ifndef SIGEV_PAD_SIZE
+#define SIGEV_PAD_SIZE  ((SIGEV_MAX_SIZE/sizeof(int)) - 3)
+#endif
+
+typedef struct sigevent {
+  sigval_t sigev_value;
+  int sigev_signo;
+  int sigev_notify;
+  union {
+    int _pad[SIGEV_PAD_SIZE];
+    int _tid;
+
+    struct {
+      void(*_function)(sigval_t);
+      void*_attribute; /* really pthread_attr_t */
+    } _sigev_thread;
+  } _sigev_un;
+} sigevent_t;
+
+#define sigev_notify_function   _sigev_un._sigev_thread._function
+#define sigev_notify_attributes _sigev_un._sigev_thread._attribute
+#define sigev_notify_thread_id  _sigev_un._tid
+
 typedef struct sigaltstack {
 #if defined(__mips__)
   void *ss_sp;
@@ -496,6 +525,8 @@ int kill(pid_t pid, int sig) __THROW;
 
 int sigaction(int signum, const struct sigaction *act, struct sigaction *oldact) __THROW;
 
+#include <sys/time.h>
+
 int sigtimedwait(const sigset_t *mask, siginfo_t *info, const struct timespec *ts) __THROW;
 int sigqueueinfo(int pid, int sig, siginfo_t *info) __THROW;
 int siginterrupt(int sig, int flag) __THROW;
