@@ -3,16 +3,10 @@
 
 extern int socketcall(int callno,long* args);
 
-#ifdef __i386__
-int __libc_sendto(int a);
-int __libc_sendto(int a) {
-  return socketcall(SYS_SENDTO, (long*)&a);
-#else
 int __libc_sendto(int a, const void * b, size_t c, int flags, void *to, int tolen);
 int __libc_sendto(int a, const void * b, size_t c, int flags, void *to, int tolen) {
   unsigned long args[] = { a, (long) b, c, flags, (long) to, tolen };
   return socketcall(SYS_SENDTO, args);
-#endif
 }
 
 int sendto(int a, const void * b, size_t c, int flags, const struct sockaddr* to, socklen_t tolen)
