@@ -25,7 +25,10 @@ void __maplocaltime(void) {
   tzlen=0;
   if ((fd=open("/etc/localtime",O_RDONLY))<0) return;
   len=lseek(fd,0,SEEK_END);
-  if ((tzfile=mmap(0,len,PROT_READ,MAP_PRIVATE,fd,0))==MAP_FAILED) return;
+  if ((tzfile=mmap(0,len,PROT_READ,MAP_PRIVATE,fd,0))==MAP_FAILED) {
+    close(fd);
+    return;
+  }
   close(fd);
   if (len<44 || ntohl(*(int*)tzfile) != 0x545a6966) {
     munmap(tzfile,len);
